@@ -146,6 +146,10 @@ def test_wildcard_model_import():
 def test_models_import_wildcard():
     mi = modelindex.load("tests/test-mi/13_wildcard_model_imports/mi8.yml")
 
+    err = mi.check(silent=True)
+    assert len(err) == 1
+    assert "docs/inception-v3-readme.md" in err[0]
+
     assert len(mi.collections) == 1
     assert len(mi.models) == 2
 
@@ -159,3 +163,24 @@ def test_models_import_wildcard():
 
     assert mi.models[0].readme == "models_md/m1.md"
     assert mi.models[1].readme == "models_md/m2.md"
+
+
+def test_readme_content():
+    mi = modelindex.load("tests/test-mi/14_readme_contents/")
+
+    assert len(mi.models) == 2
+    assert mi.models[0].readme_content() == "This is some custom readme here."
+    assert mi.models[1].readme_content() == "Another custom readme"
+
+    mi = modelindex.load("tests/test-mi/14_readme_contents/mi2.yml")
+
+    err = mi.check(silent=True)
+    assert len(err) == 1
+    assert "docs/inception-v3-readme.md" in err[0]
+
+    assert len(mi.collections) == 1
+    assert len(mi.models) == 2
+
+    assert "something here." in mi.models[0].readme_content()
+    assert "# Second here" in mi.models[1].readme_content()
+
